@@ -1,3 +1,5 @@
 from .plot_map import plot_map,plotscale
 from .CoordinatesConverter import gcj02tobd09,bd09togcj02,wgs84togcj02,gcj02towgs84,wgs84tobd09,bd09towgs84,getdistance
 from .grids import *
+from .ckdnearest import *
+__version__ = 0.2.3
\ No newline at end of file
